;; Generated package description from ztree.el  -*- no-byte-compile: t -*-
(define-package "ztree" "1.0.6.0.20210409.184115" "Text mode directory tree" '((cl-lib "0")) :keywords '("files" "tools") :authors '(("Alexey Veretennikov" . "alexey.veretennikov@gmail.com")) :maintainer '("Alexey Veretennikov" . "alexey.veretennikov@gmail.com") :url "https://github.com/fourier/ztree")
